#ifndef EEPROM_H_
#define EEPROM_H_

#define  USE_EE_IE	0		//1使用EE中断

/*写DATA EEPROM控制寄存器:NVMCTL0/NVMCTL1 --------------------------------------------------------*/
/*DATA EEPROM数据寄存器低8位:NVMDATAL--------------------------------------------------------*/
/*DATA EEPROM 地址数据指针低8位:NVMADDRL --------------------------------------------------------*/


extern	s_Dataeeprom_Buffer Dataeeprom_Buffer;  //结构定义在KF8_Type_Define.h中


unsigned char Dataeeprom_SingleDate_Read(unsigned char addr);
void Dataeeprom_Data_Read(unsigned char addr,unsigned char len);

void Dataeeprom_SingleData_Write(unsigned char addr,unsigned char value);
void Dataeeprom_Data_Write(unsigned char addr,unsigned char len);

#endif /* EEPROM_H_ */
